import dotenv
import requests
from discord import SyncWebhook
from datetime import datetime as dt
import feedparser

# initialise variables
new_ts = dt.now()
old_ts = ''

# read in old timestamp if it exists
try:
    old_ts = dt.strptime(open('last_check','r').read(),'%Y-%m-%d %H:%M:%S:%f')
except:
    old_ts = dt.strptime('20230101000000','%Y%m%d%H%M%S')

# load in the relevant .env variables
dotenv.load_dotenv()
conf = dotenv.dotenv_values()
discord_user = conf['DISCORD_USERNAME']
dicord_webhook_url = conf['DISCORD_WEBHOOK_TEST']
webhook = SyncWebhook.from_url(conf['DISCORD_WEBHOOK_TEST'])

# list with urls to check
the_urls = [
    'https://github.com/mastodon/mastodon/releases.atom',
    'https://github.com/hometown-fork/hometown/releases.atom',
    'https://git.joinfirefish.org/firefish/firefish/tags?format=atom',
    'https://akkoma.dev/AkkomaGang/akkoma/releases.atom',
    'https://github.com/superseriousbusiness/gotosocial/releases.atom'
]

# loop through urls for latest release
for url in the_urls:
    release = feedparser.parse(url)
    release_date = dt.strptime(release['entries'][0]['updated'], '%Y-%m-%dT%H:%M:%SZ')
    release_version = release['entries'][0]['title']
    release_link = release['entries'][0]['link']
    if release_date > old_ts:
        webhook.send('new release: ' + release_version + '\n' + release_link)

# write out current check timestamp to file for next check.
with open('last_check','w') as last_check:
    print(new_ts, file=last_check)
